---
applies_to: ["aws-sdk-rust"]
authors: ["Velfi"]
references: ["smithy-rs#3583"]
breaking: false
new_feature: true
bug_fix: false
---

It is now possible to disable payload signing through an operation customization.

```rust
async fn put_example_object(client: &aws_sdk_s3::Client) {
    let res = client
        .put_object()
        .bucket("test-bucket")
        .key("test-key")
        .body(ByteStream::from_static(b"Hello, world!"))
        .customize()
        // Setting this will disable payload signing.
        .disable_payload_signing()
        .send()
        .await;
}
```

Disabling payload signing will result in a small speedup at the cost of removing a data integrity check.
However, this is an advanced feature and **may not be supported by all services/operations**.
